/* ======================================================================
 * load.cc
 * 
 * This file is part of MeshIO, the general and extensible 3D mesh I/O
 * library.
 * Copyright (c) 1999, 2000 Niklas Elmqvist. All rights reserved.
 *
 * File created 1999-06-30 by Niklas Elmqvist <d97elm@dtek.chalmers.se>.
 * 
 * Chalmers Medialab
 *      <http://www.medialab.chalmers.se>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 *
 * ======================================================================
 */

// -- System Includes
#include <stdlib.h>
#include <string.h>
#include <stdio.h>

// -- Local Includes
#include "meshio.hh"
#include "utils.hh"

using namespace MeshIO;

// -- Code Segment

mioResult MeshIO::mioLoad(const char *filename, MeshSet *mset)
{
    char *suffix;

    // Find the last period in the string
    suffix = strrchr(filename, '.');
    
    // Did we find it?
    if (suffix == NULL)
	return MIO_NO_FILETYPE;
    
    // Load the file depending on the file extension
    if (strcmp(suffix, ".3ds") == 0 || strcmp(suffix, ".3DS") == 0) {
	return mio3DSLoad(filename, mset);
    }
    else if (strcmp(suffix, ".raw") == 0 || strcmp(suffix, ".RAW") == 0) {
	return mioRawLoad(filename, mset);
    }
    
    // No loader found!
    return MIO_NO_FILETYPE;
}
